==> FreeDoko_0.7.8.src.zip: FreeDoko_0.7.8/src/player/ai/VirtualGamesInterface.h <==
/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *    
 *   Copyright (C) 2001-2010  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or 
 *   modify it under the terms of the GNU General Public License as 
 *   published by the Free Software Foundation; either version 2 of 
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details. 
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 *********************************************************************/

#ifndef CLASS_VIRTUALGAMESINTERFACE_HEADER
#define CLASS_VIRTUALGAMESINTERFACE_HEADER

#include "../aiconfig.h"
#include "../../basistypes.h"
#include "../../game/game.h"

class Hand;

/// reine Virtuelle Klasse die fuer W_virtual_games implementiert werden muss
class VirtualGamesInterface {
  public:	
    VirtualGamesInterface() { }
    virtual ~VirtualGamesInterface() { }

    virtual Hand const& handofplayer( Player const& player ) const = 0;
    virtual Hand const& handofplayer( unsigned const playerno ) const 
    { return this->handofplayer( this->game().player(playerno) ); }
    virtual Team teamofplayer( Player const& player ) const = 0;
    virtual Team teamofplayer( unsigned const playerno ) const 
    { return this->teamofplayer( this->game().player(playerno) ); }
    virtual Team guessedteamofplayer( Player const& player )    const
    { return TEAM::maybe_to_team(this->teamofplayer(player)); }
    virtual Team guessedteamofplayer( unsigned const playerno )    const
    { return TEAM::maybe_to_team(this->teamofplayer(playerno)); }

    virtual vector<Player*> create_virtual_players() const = 0;

    virtual Hand const& hand() const = 0;
    virtual Team team() const = 0;
    virtual unsigned no() const = 0;
    virtual Game const& game() const = 0;
    virtual unsigned const last_trick_to_calculate() const = 0;

    virtual bool value(const Aiconfig::TypeBool& type) const = 0;
    virtual unsigned value(const Aiconfig::TypeUnsigned& type) const = 0;
    virtual Card value(const Aiconfig::TypeCard& type) const = 0;
    virtual unsigned color_runs(const Card::Color c) const = 0;

    virtual bool colorjabbed(const Card::TColor c) const = 0;

    virtual bool jabbedbyownteam(const Card::TColor c) const = 0;
    virtual bool jabbedbyotherteam(const Card::TColor c) const = 0;
    virtual Card trump_card_limit() const = 0;
}; // class VirtualGamesInterface

#endif // #ifndef CLASS_VIRTUALGAMESINTERFACE_HEADER

==> FreeDoko_0.7.9.src.zip: FreeDoko_0.7.9/src/player/ai/VirtualGamesInterface.h <==
/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *    
 *   Copyright (C) 2001-2011  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or 
 *   modify it under the terms of the GNU General Public License as 
 *   published by the Free Software Foundation; either version 2 of 
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details. 
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 *********************************************************************/

#ifndef CLASS_VIRTUALGAMESINTERFACE_HEADER
#define CLASS_VIRTUALGAMESINTERFACE_HEADER

#include "../aiconfig.h"
#include "../../basistypes.h"
#include "../../game/game.h"

class Hand;

/// reine Virtuelle Klasse die fuer W_virtual_games implementiert werden muss
class VirtualGamesInterface {
  public:	
    VirtualGamesInterface() { }
    virtual ~VirtualGamesInterface() { }

    virtual Hand const& handofplayer( Player const& player ) const = 0;
    virtual Hand const& handofplayer( unsigned const playerno ) const 
    { return this->handofplayer( this->game().player(playerno) ); }
    virtual Team teamofplayer( Player const& player ) const = 0;
    virtual Team teamofplayer( unsigned const playerno ) const 
    { return this->teamofplayer( this->game().player(playerno) ); }
    virtual Team guessedteamofplayer( Player const& player )    const
    { return TEAM::maybe_to_team(this->teamofplayer(player)); }
    virtual Team guessedteamofplayer( unsigned const playerno )    const
    { return TEAM::maybe_to_team(this->teamofplayer(playerno)); }

    virtual vector<Player*> create_virtual_players() const = 0;

    virtual Hand const& hand() const = 0;
    virtual Team team() const = 0;
    virtual unsigned no() const = 0;
    virtual Game const& game() const = 0;
    virtual unsigned const last_trick_to_calculate() const = 0;

    virtual bool value(const Aiconfig::TypeBool& type) const = 0;
    virtual int value(const Aiconfig::TypeInt& type) const = 0;
    virtual Card value(const Aiconfig::TypeCard& type) const = 0;
    virtual unsigned color_runs(const Card::Color c) const = 0;

    virtual bool colorjabbed(const Card::TColor c) const = 0;

    virtual bool jabbedbyownteam(const Card::TColor c) const = 0;
    virtual bool jabbedbyotherteam(const Card::TColor c) const = 0;
    virtual Card trump_card_limit() const = 0;
}; // class VirtualGamesInterface

#endif // #ifndef CLASS_VIRTUALGAMESINTERFACE_HEADER
